@@ -47,7 +47,7 @@
 "places.Country128":"Luxemburg",
 "places.Country129":"Makao",
 "nokia.maps.pfw.spices.sncwaypointspice.routeplanner":"Útvonal tervező",
-"mapPlayer_4_settings_landmarks_txt_title":"3D Landmarks",
+"mapPlayer_4_settings_landmarks_txt_title":"3D tereptárgyak",
 "places.Country130":"Macedónia",
 "places.Country131":"Madagaszkár",
 "settingTimeFormat24h":"24 órás",
@@ -280,7 +280,7 @@
 "places.subcategory59":"Tenger alatti látványosság",
 "defaultSearchTerm":"pl. egy cím, üzlet vagy hely név",
 "mapPlayer_18_buttonsArray_mapview_buttonLabel_satellite":"Műhold",
-"nokia.maps.pfw.ui.blockersettings.ferries":"kompok",
+"nokia.maps.pfw.ui.blockersettings.ferries":"Kompok",
 "nokia.maps.pfw.turn.lightright.street":"fordulj kissé jobbra -",
 "places.subcategory60":"Erdő, puszta vagy egyéb növényzet",
 "call":"Hívás",
@@ -353,7 +353,7 @@
 "about.txt1":"Ovi Maps 1.01",
 "about.txt2":"www.nokia.com/maps/support",
 "about.txt3":"maps.ovi.com",
-"readTnC":"Read Terms and Conditions",
+"readTnC":"Általános Szerződési Feltételek",
 "about.txt4":"&copy; 2008 NAVTEQ<br/>All Rights Reserved<br/>www.navteq.com",
 "about.txt5":"&copy; 2008 NavInfo Co Ltd.<br/>All Rights Reserved<br/>www.nav2.com.cn",
 "mapPlayer_27_mapControl_scale_toolTip_expand":"Vonalzó",
@@ -480,7 +480,7 @@
 "nextTitle":"Következő",
 "mapPlayer_22_buttonsArray_traffic_toolTip_off":"Forgalom mutatása",
 "search":"Keresés",
-"QTN_POISEARCH_ITEM08_01":"3D landmarks",
+"QTN_POISEARCH_ITEM08_01":"3D tereptárgyak",
 "nokia.maps.pfw.action.end.street":"megérkeztél az uticélhoz",
 "places.Country230":"Ukrajna",
 "places.Country231":"Egyesült Arab Emirátusok",
@@ -753,5 +753,13 @@
 "nokia.maps.pfw.ui.sncapplicationui.btnclose":"Bezár",
 "nokia.maps.pfw.unit.kilometersperhour":"km/h",
 "nokia.maps.pfw.action.ferry":"hajts fel a kompra",
-"errorConnectionFailure":"A kereső szolgáltatás nem elérhető. Ellenőrizd, hogy a készülék csatlakozik e az internetre."
-};
\ No newline at end of file
+"errorConnectionFailure":"A kereső szolgáltatás nem elérhető. Ellenőrizd, hogy a készülék csatlakozik e az internetre.",
+"about_maps":"Ovi Maps névjegye",
+"tips":"Tippek",
+"three_d":"3D Nézet",
+"nokia.maps.pfw.ui.waypointspice.searchstart":"Kiindulópont keresése",
+"dashboard.getDirections":"Útbaejt",
+"dashboard.clearMap":"Útvonal törlése",
+"dashboard.findPlaces":"Keresés",
+"searchInProgress":"Keresés folyamatban ...",
+};
